abacusai.eda_data_consistency — AbacusAI documentation

# abacusai.eda_data_consistency

## Classes

`EdaDataConsistency` | Eda Data Consistency, contained the duplicates in the base version, Comparison version, Deletions between the base and comparison and feature transformations between the base and comparison data.

## Module Contents

class abacusai.eda_data_consistency.EdaDataConsistency(client, columnNames=None, primaryKeys=None, transformationColumnNames=None, baseDuplicates={}, compareDuplicates={}, deletions={}, transformations={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Eda Data Consistency, contained the duplicates in the base version, Comparison version, Deletions between the base and comparison and feature transformations between the base and comparison data.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - columnNames (list) – Name of all the features in the data

    - primaryKeys (list) – Name of the primary keys in the data

    - transformationColumnNames (list) – Name of all the features that are not the primary keys

    - baseDuplicates (DataConsistencyDuplication) – A DataConsistencyDuplication describing the number of duplicates within the data

    - compareDuplicates (DataConsistencyDuplication) – A DataConsistencyDuplication describing the number of duplicates within the data

    - deletions (DataConsistencyDuplication) – A DataConsistencyDeletion describing the number of deletion between two versions in the data

    - transformations (DataConsistencyTransformation) – A DataConsistencyTransformation the number of changes that occured per feature in the data

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict